#
# spec file for package perl-DBIx-Connector
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name DBIx-Connector
Name:           perl-DBIx-Connector
Version:        0.600.0
Release:        1.1
# 0.60 -> normalize -> 0.600.0
%define cpan_version 0.60
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Fast, safe DBI connection and transaction management
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/A/AR/ARISTOTLE/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(DBI) >= 1.605
Requires:       perl(DBI) >= 1.605
Provides:       perl(DBIx::Connector) = %{version}
Provides:       perl(DBIx::Connector::Driver) = %{version}
Provides:       perl(DBIx::Connector::Driver::Firebird) = %{version}
Provides:       perl(DBIx::Connector::Driver::MSSQL) = %{version}
Provides:       perl(DBIx::Connector::Driver::MariaDB) = %{version}
Provides:       perl(DBIx::Connector::Driver::Oracle) = %{version}
Provides:       perl(DBIx::Connector::Driver::Pg) = %{version}
Provides:       perl(DBIx::Connector::Driver::SQLite) = %{version}
Provides:       perl(DBIx::Connector::Driver::mysql) = %{version}
Provides:       perl(DBIx::Connector::RollbackError) = 0.58
Provides:       perl(DBIx::Connector::SvpRollbackError) = 0.58
Provides:       perl(DBIx::Connector::TxnRollbackError) = 0.58
%undefine       __perllib_provides
Recommends:     perl(DBI) >= 1.614
%{perl_requires}

%description
DBIx::Connector provides a simple interface for fast and safe DBI
connection and transaction management. Connecting to a database can be
expensive; you don't want your application to re-connect every time you
need to run a query. The efficient thing to do is to hang on to a database
handle to maintain a connection to the database in order to minimize that
overhead. DBIx::Connector lets you do that without having to worry about
dropped or corrupted connections.

You might be familiar with Apache::DBI and with the DBI's
'connect_cached()' constructor. DBIx::Connector serves a similar need, but
does a much better job. How is it different? I'm glad you asked!

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Mon Oct 21 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.600.0 (0.60)
  see /usr/share/doc/packages/perl-DBIx-Connector/Changes
  0.60  Mon 21 Oct 2024
  - MariaDB support (Issue #50)
  - Fix for leaking $@ from driver constructor (Issue #51)
  - Fix for swallowing driver compile errors
* Mon Jul  3 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.59
  see /usr/share/doc/packages/perl-DBIx-Connector/Changes
  0.59  Sun 02 Jul 2023
  - Fix for Windows t/load.t failures
* Tue Aug 30 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.58
  see /usr/share/doc/packages/perl-DBIx-Connector/Changes
* Tue Sep 28 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.57
  see /usr/share/doc/packages/perl-DBIx-Connector/Changes
* Tue Mar 22 2016 coolo@suse.com
- updated to 0.56
  see /usr/share/doc/packages/perl-DBIx-Connector/Changes
  0.56  2016-03-16T17:07:05Z
  - Added Firebird support, thanks to Stefan Suciu.
  - Fixed SQLite savepoint support to properly detect SQlite versions 3.9
    and higher.
  - Restored MySQL savepoint testing when the DBICTEST_* environment
    variables are set.
* Sun Feb  7 2016 coolo@suse.com
- updated to 0.55
  see /usr/share/doc/packages/perl-DBIx-Connector/Changes
  0.55  2016-02-05T18:59:24Z
  - Added versions to the RollbackError exception classes to make PAUSE
    happy.
  0.54  2016-02-05T18:52:44Z
  - Removeed the Pod tests from the distribution.
  - Fixed the example code for handling `rollback_error` exceptions in the
    documentation to properly wrap the transaction in an exception
    handler. Patch from Perlover (issue #32).
  - Improved handling of connection failures when RaiseError (or
    HandleError) is not set. Thanks to Andreas Huber for the report and
    fix.
  - Document that `$_` is set locally, not globally, in the methods that
    set it. Suggested by William Lindley.
  - The disconnect method no longer longer remove entries from the DBI
    handle's CachedKids attribute. That behavior appears to be a
    workaround for a database we don't (yet) support.
  - Fixed a test failure where the test system has the `$DBI_DSN` or
    `$DBI_DRIVER` environment variable set. Thanks to Erik Rijkers for the
    patch.
  - Added recommendation to use DBD::Pg 3.5.0 or later to the Pg driver.
    Earlier versions had an incorrect implementation of the `ping()`
    method (Issue #41).
* Thu Dec  4 2014 ncutler@suse.com
- updated to upstream version 0.53
  0.53  2013-03-20T06:04:34Z
  - Fixed some documentation typos, thanks to Mike O'Regan (Issue #22).
  - Fixed issue where an connection failure caused an unhelpful error
    (Issue #26).
  0.52  2012-05-29T18:32:42Z
  - The DBI params are now encapsulated in a code reference, rather than
    stored as the passed array, so that the password is less likely to be
    displayed in a dump. Idea borrowed from Rose::DB. Patch from Brad
    Bowman.
  - Eliminated warning about the non-portability of a v-string on older
    Perls. Thanks to Mark Lawrence for the report (Issue #17).
  - Removed a couple of leftover examples of the feature removed
    in v0.50. Thanks to Randy Stauner for the patch!
  - Eliminated more "Use of qw(...) as parentheses" syntax errors in tests
    when running on Perl 5.17.
  - Add mention of DBI Callbacks parameter to the docs, as folks often ask
    for this functionality, not realizing that the DBI already provides
    it. Randy Stauner.
* Mon Feb 27 2012 coolo@suse.com
- initial package 0.51
  * created by cpanspec 1.78.06
